<?php

/**
 * Handles and defines all the plugin variables
 *
 * @link       http://www.emojics.com
 * @since      1.0.0
 * @package    Emojics_WP
 * @subpackage Emojics_WP/includes
 * @author     Stefano <stefano.marra1987@gmail.com>
 */
class Emojics_Setup {

	/**
	 * Register default settings tab
	 *
	 * @since 1.0.0
	 */
	private $tabs = array(
			'general'      => 'General'
		);

	private $tab_sections = array(
			// 'general' 	=> array(
			// 	'main'               => 'General Notifications',
			// 	'purchase_receipts'  => 'Purchase Receipts',
			// 	'sale_notifications' => 'New Sale Notifications'
			// )
		);

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Plugin custom post types
	 *
	 * @since    1.0.0
	 */
	public static function post_types() {

		return [
			// 'co_contest' => array(
			// 	'labels' 	=> array(
			// 			'name'          => __( 'Contests', EMJCS_DOMAIN ),
			// 			'singular_name' => __( 'Contest', EMJCS_DOMAIN ),
			// 			'all_items' 	=> __( 'All Contests', EMJCS_DOMAIN ),
			// 			'new_item'      => __( 'New Contest', EMJCS_DOMAIN ),
			// 			'add_new'       => __( 'Add New', EMJCS_DOMAIN ),
			// 			'add_new_item'  => __( 'Add New Contest', EMJCS_DOMAIN ),
			// 			'edit_item'     => __( 'Edit Contest', EMJCS_DOMAIN ),
			// 			'view_item'     => __( 'View Contest', EMJCS_DOMAIN ),
			// 			'search_items'  => __( 'Search Contests', EMJCS_DOMAIN ),
			// 		),
			// 	'rewrite'     => array( 'slug' => 'contest' ),
			// 	'public'      => true,
			// 	'has_archive' => false,
			// 	'menu_icon'   => 'dashicons-admin-multisite',
			// 	'supports' 	  => array( 'title', 'author' ),
			// 	'post_meta'	=> array(
			// 			'cocontest_contest_id' 		=> array(
			// 					'type'        => 'text',
			// 					'name'        => __('Contest ID', EMJCS_DOMAIN),
			// 					'class'       => '',
			// 					'default' 	  => '',
			// 					'placeholder' => '',
			// 					'description' => __('', EMJCS_DOMAIN),
			// 					'disabled' 	  => true
			// 				)
			// 		)
			// ),
			// 'co_application' => array(
			// 	'labels' 	=> array(
			// 			'name'          => __( 'Applications', EMJCS_DOMAIN ),
			// 			'singular_name' => __( 'Application', EMJCS_DOMAIN ),
			// 			'all_items' 	=> __( 'All Applications', EMJCS_DOMAIN ),
			// 			'new_item'      => __( 'New Application', EMJCS_DOMAIN ),
			// 			'add_new'       => __( 'Add New', EMJCS_DOMAIN ),
			// 			'add_new_item'  => __( 'Add New Application', EMJCS_DOMAIN ),
			// 			'edit_item'     => __( 'Edit Application', EMJCS_DOMAIN ),
			// 			'view_item'     => __( 'View Application', EMJCS_DOMAIN ),
			// 			'search_items'  => __( 'Search Applications', EMJCS_DOMAIN ),
			// 		),
			// 	'rewrite'     => array( 'slug' => 'application' ),
			// 	'public'      => true,
			// 	'has_archive' => false,
			// 	'menu_icon'   => 'dashicons-admin-home',
			// 	'supports' 	  => array( 'title', 'author' ),
			// 	'post_meta'	=> array(
			// 			'cocontest_contest_id' 		=> array(
			// 					'type'        => 'text',
			// 					'name'        => __('Contest ID', EMJCS_DOMAIN),
			// 					'class'       => '',
			// 					'default' 	  => '',
			// 					'placeholder' => '',
			// 					'description' => __('', EMJCS_DOMAIN),
			// 					'disabled' 	  => true
			// 				),
			// 			'cocontest_application_id' 		=> array(
			// 					'type'        => 'text',
			// 					'name'        => __('Application ID', EMJCS_DOMAIN),
			// 					'class'       => '',
			// 					'default' 	  => '',
			// 					'placeholder' => '',
			// 					'description' => __('', EMJCS_DOMAIN),
			// 					'disabled' 	  => true
			// 				),
			// 			'cocontest_applicationproject_id' 		=> array(
			// 					'type'        => 'text',
			// 					'name'        => __('Project ID', EMJCS_DOMAIN),
			// 					'class'       => '',
			// 					'default' 	  => '',
			// 					'placeholder' => '',
			// 					'description' => __('Application Project', EMJCS_DOMAIN),
			// 					'disabled' 	  => true
			// 				),
			// 			'cocontest_application_number' 		=> array(
			// 					'type'        => 'text',
			// 					'name'        => __('Number', EMJCS_DOMAIN),
			// 					'class'       => '',
			// 					'default' 	  => '',
			// 					'placeholder' => '',
			// 					'description' => __('Application Number', EMJCS_DOMAIN),
			// 					'disabled' 	  => true
			// 				)
			// 		)
			// )
		];
	}

	/**
	 * Register plugin custom post type
	 *
	 * @since 	1.0.0
	 */
	public function register_post_types() {

		$post_types = Emojics_Setup::post_types();

		foreach($post_types as $post_type => $type_opt) {
			register_post_type($post_type, array(
				'labels' 	=> array(
								'name'          => $type_opt['labels']['name'],
								'singular_name' => $type_opt['labels']['singular_name'],
								'all_items' 	 => $type_opt['labels']['all_items'],
								'new_item'      => $type_opt['labels']['new_item'],
								'add_new'       => $type_opt['labels']['add_new'],
								'add_new_item'  => $type_opt['labels']['add_new_item'],
								'edit_item'     => $type_opt['labels']['edit_item'],
								'view_item'     => $type_opt['labels']['view_item'],
								'search_items'  => $type_opt['labels']['search_items'],
							),
				'rewrite'     => $type_opt['rewrite'],
				'public'      => $type_opt['public'],
				'has_archive' => $type_opt['has_archive'],
				'menu_icon'   => $type_opt['menu_icon'],
				'supports' 	  => $type_opt['supports']
			));

			if ( isset( $type_opt['post_status'] ) && is_array( $type_opt['post_status'] ) ) {
				foreach( $type_opt['post_status'] as $status_name => $status_args ) {
					register_post_status( $status_name, array(
						'label'                     => _x( $status_args['label'], EMJCS_DOMAIN ),
						'public'                    => true,
						'show_in_admin_all_list'    => false,
						'show_in_admin_status_list' => true,
						'label_count'               => _n_noop( $status_args['label'] . ' <span class="count">(%s)</span>', $status_args['label'] . ' <span class="count">(%s)</span>' )
					) );
				}
			}

		}

		flush_rewrite_rules();
	}

	/**
	 * Register Admin Menu
	 *
	 * @since 1.0.0
	 */
	public function register_plugin_pages() {
		// add_options_page( 'Emojics', 'Emojics', 'manage_options', 'emojics_settings', array(&$this, 'settings_page' ));

		$api_key = emojics_get_option('api_key', false);


		add_menu_page(
			'Emojics',
			'Emojics',
			'manage_options',
			'emojics_dashboard',
			array(&$this, 'dashboard_page' ),
			EMJCS_URL . 'admin/img/emojics-icon.svg'
		);

		add_submenu_page(
			'emojics_dashboard',
			'Dashboard',
			'Dashboard',
		    'manage_options',
		    'emojics_dashboard',
		    array(&$this, 'dashboard_page')
		);

		if ( $api_key ) {
			add_submenu_page(
				'emojics_dashboard',
				'Settings',
				'Advanced Settings',
			    'manage_options',
			    'emojics_settings',
			    array(&$this, 'settings_page' )
			);
		}
	}

	/**
	 * Callback Function for settings page
	 *
	 * @since 1.0.0
	 */
	public function settings_page() {
		$tab = ( isset( $_GET['tab'] ) && !empty( $_GET['tab'] ) ) ? $_GET['tab'] : 'general';
		$this->settings_tabs( $tab );
	}

	/**
	 *
	 *
	 * @since 1.2.0
	 */
	public function authentication_page() {
		include( EMJCS_DIR . 'admin/templates/page-authenticate.php');
	}

	/**
	 *
	 *
	 * @since 1.2.0
	 */
	public function show_authentication_page_if_needed() {
		$api_key = emojics_get_option('api_key', false);
		$js_code = emojics_get_option('js_code', false);

		if ( !$api_key || !$js_code ) {
			$this->authentication_page();
			return true;
		}

		return false;
	}

	/**
	 * Callback Function for dashboard page
	 *
	 * @since 1.2.0
	 */
	public function dashboard_page() {
		if ( !$this->show_authentication_page_if_needed() ) {
			include( EMJCS_DIR . 'admin/templates/page-dashboard.php');
		}
	}

	/**
	 * Shows tabs and handles the selected tab
	 *
	 * @since 1.0.0
	 */
	public function settings_tabs($curr = 'general') {

		if ( !$this->show_authentication_page_if_needed() ) {
			if ( count($this->tabs) > 1 ) {
				echo '<h2 class="nav-tab-wrapper">';
				foreach( $this->tabs as $tab => $name ){
					$class = ( $tab == $curr ) ? ' nav-tab-active' : '';
					echo '<a class="nav-tab' . $class . '" href="admin.php?page=emojics_settings&tab=' . $tab . '">' . $name . '</a>';
				}
				echo '</h2>';
			}

			if ( isset( $this->tab_sections[$curr] ) ) {
				$curr_section = ( isset( $_GET['section'] ) && !empty( $_GET['section'] ) ) ? $_GET['section'] : 'main';

				echo '<div>';
				echo '<ul class="subsubsub">';
				foreach( $this->tab_sections[$curr] as $section => $section_name ) {
					$class = ( $curr_section == $section ) ? ' current' : '';
					echo '<li><a class="' . $class . '" href="admin.php?page=cocontest_one_to_one_settings&tab=' . $curr . '&section=' . $section . '">' . $section_name . '</a> | </li>';
				}
				echo '</ul>';
				echo '</div>';

				echo '<h3 class="section-title">' . $this->tab_sections[$curr][$curr_section] . '</h3>';
			}

			switch ( $curr ) {
				case 'general':
				default:
					include( EMJCS_DIR . 'admin/templates/settings-general.php');
					break;
			}
		}
	}

	/**
	 * Register all plugin options
	 *
	 * @since 1.0.0
	 */
	public function register_plugin_options() {
		register_setting( 'emojics_settings_general', '_emojics_api_key' );
		register_setting( 'emojics_settings_general', '_emojics_widget_active' );
		register_setting( 'emojics_settings_general', '_emojics_widget_position' );
		register_setting( 'emojics_settings_general', '_emojics_widget_exclude' );
		register_setting( 'emojics_settings_general', '_emojics_widget_configs' );
	}
}
